@@ -1,24 +1,24 @@
-use async_std::{
-    fs::{File, OpenOptions},
-    io::{self, IoSlice, IoSliceMut, Read, Write},
-    path::Path,
-};
+use async_std::fs::{File, OpenOptions};
+use async_std::io::{self, IoSlice, IoSliceMut, Read, Write};
+use async_std::path::Path;
 use io_lifetimes::{FromFilelike, IntoFilelike};
-use std::{
-    pin::Pin,
-    task::{Context, Poll},
-};
+use std::pin::Pin;
+use std::task::{Context, Poll};
 #[cfg(windows)]
 use {
     ::async_std::os::windows::io::{AsRawHandle, IntoRawHandle, RawHandle},
-    io_lifetimes::{AsFilelike, AsHandle, BorrowedHandle},
-    unsafe_io::os::windows::{AsRawHandleOrSocket, IntoRawHandleOrSocket, RawHandleOrSocket},
+    io_lifetimes::{AsFilelike, AsHandle, BorrowedHandle, IntoHandle, OwnedHandle},
+    unsafe_io::os::windows::{
+        AsHandleOrSocket, AsRawHandleOrSocket, AsRawReadWriteHandleOrSocket,
+        AsReadWriteHandleOrSocket, BorrowedHandleOrSocket, IntoHandleOrSocket,
+        IntoRawHandleOrSocket, OwnedHandleOrSocket, RawHandleOrSocket,
+    },
 };
 #[cfg(not(windows))]
 use {
-    io_lifetimes::{AsFd, BorrowedFd},
-    posish::fs::FileTypeExt,
-    unsafe_io::os::posish::{AsRawFd, IntoRawFd, RawFd},
+    io_lifetimes::{AsFd, BorrowedFd, IntoFd, OwnedFd},
+    rsix::fs::FileTypeExt,
+    unsafe_io::os::rsix::{AsRawFd, AsRawReadWriteFd, AsReadWriteFd, IntoRawFd, RawFd},
 };
 
 /// An unbuffered character device.
@@ -111,7 +111,7 @@ impl AsyncStdCharDevice {
     pub fn num_ready_bytes(&self) -> io::Result<u64> {
         #[cfg(not(windows))]
         {
-            Ok(posish::io::ioctl_fionread(self)?)
+            Ok(rsix::io::ioctl_fionread(self)?)
         }
 
         #[cfg(windows)]
@@ -211,6 +211,14 @@ impl AsHandle for AsyncStdCharDevice {
     }
 }
 
+#[cfg(windows)]
+impl AsHandleOrSocket for AsyncStdCharDevice {
+    #[inline]
+    fn as_handle_or_socket(&self) -> BorrowedHandleOrSocket<'_> {
+        self.0.as_handle_or_socket()
+    }
+}
+
 #[cfg(not(windows))]
 impl IntoRawFd for AsyncStdCharDevice {
     #[inline]
@@ -219,6 +227,14 @@ impl IntoRawFd for AsyncStdCharDevice {
     }
 }
 
+#[cfg(not(windows))]
+impl IntoFd for AsyncStdCharDevice {
+    #[inline]
+    fn into_fd(self) -> OwnedFd {
+        self.0.into_fd()
+    }
+}
+
 #[cfg(windows)]
 impl IntoRawHandle for AsyncStdCharDevice {
     #[inline]
@@ -227,6 +243,14 @@ impl IntoRawHandle for AsyncStdCharDevice {
     }
 }
 
+#[cfg(windows)]
+impl IntoHandle for AsyncStdCharDevice {
+    #[inline]
+    fn into_handle(self) -> OwnedHandle {
+        self.0.into_handle()
+    }
+}
+
 #[cfg(windows)]
 impl IntoRawHandleOrSocket for AsyncStdCharDevice {
     #[inline]
@@ -234,3 +258,63 @@ impl IntoRawHandleOrSocket for AsyncStdCharDevice {
         self.0.into_raw_handle_or_socket()
     }
 }
+
+#[cfg(windows)]
+impl IntoHandleOrSocket for AsyncStdCharDevice {
+    #[inline]
+    fn into_handle_or_socket(self) -> OwnedHandleOrSocket {
+        self.0.into_handle_or_socket()
+    }
+}
+
+#[cfg(not(windows))]
+impl AsRawReadWriteFd for AsyncStdCharDevice {
+    #[inline]
+    fn as_raw_read_fd(&self) -> RawFd {
+        self.as_raw_fd()
+    }
+
+    #[inline]
+    fn as_raw_write_fd(&self) -> RawFd {
+        self.as_raw_fd()
+    }
+}
+
+#[cfg(not(windows))]
+impl AsReadWriteFd for AsyncStdCharDevice {
+    #[inline]
+    fn as_read_fd(&self) -> BorrowedFd<'_> {
+        self.as_fd()
+    }
+
+    #[inline]
+    fn as_write_fd(&self) -> BorrowedFd<'_> {
+        self.as_fd()
+    }
+}
+
+#[cfg(windows)]
+impl AsRawReadWriteHandleOrSocket for AsyncStdCharDevice {
+    #[inline]
+    fn as_raw_read_handle_or_socket(&self) -> RawHandleOrSocket {
+        self.as_raw_handle_or_socket()
+    }
+
+    #[inline]
+    fn as_raw_write_handle_or_socket(&self) -> RawHandleOrSocket {
+        self.as_raw_handle_or_socket()
+    }
+}
+
+#[cfg(windows)]
+impl AsReadWriteHandleOrSocket for AsyncStdCharDevice {
+    #[inline]
+    fn as_read_handle_or_socket(&self) -> BorrowedHandleOrSocket<'_> {
+        self.as_handle_or_socket()
+    }
+
+    #[inline]
+    fn as_write_handle_or_socket(&self) -> BorrowedHandleOrSocket<'_> {
+        self.as_handle_or_socket()
+    }
+}
