@@ -1,21 +1,23 @@
 use io_lifetimes::{FromFilelike, IntoFilelike};
-use std::{
-    fmt::Arguments,
-    fs::{File, OpenOptions},
-    io::{self, IoSlice, IoSliceMut, Read, Write},
-    path::Path,
-};
+use std::fmt::Arguments;
+use std::fs::{File, OpenOptions};
+use std::io::{self, IoSlice, IoSliceMut, Read, Write};
+use std::path::Path;
 #[cfg(not(windows))]
 use {
     io_lifetimes::{AsFd, BorrowedFd, IntoFd, OwnedFd},
-    posish::fs::FileTypeExt,
-    unsafe_io::os::posish::{AsRawFd, IntoRawFd, RawFd},
+    rsix::fs::FileTypeExt,
+    unsafe_io::os::rsix::{AsRawFd, AsRawReadWriteFd, AsReadWriteFd, IntoRawFd, RawFd},
 };
 #[cfg(windows)]
 use {
     io_lifetimes::{AsHandle, BorrowedHandle, IntoHandle, OwnedHandle},
     std::os::windows::io::{AsRawHandle, IntoRawHandle, RawHandle},
-    unsafe_io::os::windows::{AsRawHandleOrSocket, IntoRawHandleOrSocket, RawHandleOrSocket},
+    unsafe_io::os::windows::{
+        AsHandleOrSocket, AsRawHandleOrSocket, AsRawReadWriteHandleOrSocket,
+        AsReadWriteHandleOrSocket, BorrowedHandleOrSocket, IntoHandleOrSocket,
+        IntoRawHandleOrSocket, OwnedHandleOrSocket, RawHandleOrSocket,
+    },
 };
 
 /// An unbuffered character device.
@@ -105,7 +107,7 @@ impl CharDevice {
     pub fn num_ready_bytes(&self) -> io::Result<u64> {
         #[cfg(not(windows))]
         {
-            Ok(posish::io::ioctl_fionread(self)?)
+            Ok(rsix::io::ioctl_fionread(self)?)
         }
 
         #[cfg(windows)]
@@ -220,6 +222,14 @@ impl AsHandle for CharDevice {
     }
 }
 
+#[cfg(windows)]
+impl AsHandleOrSocket for CharDevice {
+    #[inline]
+    fn as_handle_or_socket(&self) -> BorrowedHandleOrSocket<'_> {
+        BorrowedHandleOrSocket::from_handle(self.0.as_handle())
+    }
+}
+
 #[cfg(windows)]
 impl AsRawHandleOrSocket for CharDevice {
     #[inline]
@@ -267,3 +277,63 @@ impl IntoRawHandleOrSocket for CharDevice {
         self.0.into_raw_handle_or_socket()
     }
 }
+
+#[cfg(windows)]
+impl IntoHandleOrSocket for CharDevice {
+    #[inline]
+    fn into_handle_or_socket(self) -> OwnedHandleOrSocket {
+        self.0.into_handle_or_socket()
+    }
+}
+
+#[cfg(not(windows))]
+impl AsRawReadWriteFd for CharDevice {
+    #[inline]
+    fn as_raw_read_fd(&self) -> RawFd {
+        self.as_raw_fd()
+    }
+
+    #[inline]
+    fn as_raw_write_fd(&self) -> RawFd {
+        self.as_raw_fd()
+    }
+}
+
+#[cfg(not(windows))]
+impl AsReadWriteFd for CharDevice {
+    #[inline]
+    fn as_read_fd(&self) -> BorrowedFd<'_> {
+        self.as_fd()
+    }
+
+    #[inline]
+    fn as_write_fd(&self) -> BorrowedFd<'_> {
+        self.as_fd()
+    }
+}
+
+#[cfg(windows)]
+impl AsRawReadWriteHandleOrSocket for CharDevice {
+    #[inline]
+    fn as_raw_read_handle_or_socket(&self) -> RawHandleOrSocket {
+        self.as_raw_handle_or_socket()
+    }
+
+    #[inline]
+    fn as_raw_write_handle_or_socket(&self) -> RawHandleOrSocket {
+        self.as_raw_handle_or_socket()
+    }
+}
+
+#[cfg(windows)]
+impl AsReadWriteHandleOrSocket for CharDevice {
+    #[inline]
+    fn as_read_handle_or_socket(&self) -> BorrowedHandleOrSocket<'_> {
+        self.as_handle_or_socket()
+    }
+
+    #[inline]
+    fn as_write_handle_or_socket(&self) -> BorrowedHandleOrSocket<'_> {
+        self.as_handle_or_socket()
+    }
+}
