@@ -1,25 +1,24 @@
 use io_lifetimes::{FromFilelike, IntoFilelike};
-use std::{
-    io::IoSlice,
-    path::Path,
-    pin::Pin,
-    task::{Context, Poll},
-};
-use tokio::{
-    fs::{File, OpenOptions},
-    io::{self, AsyncRead, AsyncWrite, ReadBuf},
-};
+use std::io::IoSlice;
+use std::path::Path;
+use std::pin::Pin;
+use std::task::{Context, Poll};
+use tokio::fs::{File, OpenOptions};
+use tokio::io::{self, AsyncRead, AsyncWrite, ReadBuf};
 #[cfg(not(windows))]
 use {
     io_lifetimes::{AsFd, BorrowedFd},
-    posish::fs::FileTypeExt,
-    unsafe_io::os::posish::{AsRawFd, RawFd},
+    rsix::fs::FileTypeExt,
+    unsafe_io::os::rsix::{AsRawFd, AsRawReadWriteFd, AsReadWriteFd, RawFd},
 };
 #[cfg(windows)]
 use {
     io_lifetimes::{AsFilelike, AsHandle, BorrowedHandle},
     std::os::windows::io::{AsRawHandle, RawHandle},
-    unsafe_io::os::windows::{AsRawHandleOrSocket, RawHandleOrSocket},
+    unsafe_io::os::windows::{
+        AsHandleOrSocket, AsRawHandleOrSocket, AsRawReadWriteHandleOrSocket,
+        AsReadWriteHandleOrSocket, BorrowedHandleOrSocket, RawHandleOrSocket,
+    },
 };
 
 /// An unbuffered character device.
@@ -109,7 +108,7 @@ impl TokioCharDevice {
     pub fn num_ready_bytes(&self) -> io::Result<u64> {
         #[cfg(not(windows))]
         {
-            Ok(posish::io::ioctl_fionread(self)?)
+            Ok(rsix::io::ioctl_fionread(self)?)
         }
 
         #[cfg(windows)]
@@ -199,3 +198,63 @@ impl AsHandle for TokioCharDevice {
         self.0.as_handle()
     }
 }
+
+#[cfg(windows)]
+impl AsHandleOrSocket for TokioCharDevice {
+    #[inline]
+    fn as_handle_or_socket(&self) -> BorrowedHandleOrSocket<'_> {
+        BorrowedHandleOrSocket::from_handle(self.0.as_handle())
+    }
+}
+
+#[cfg(not(windows))]
+impl AsRawReadWriteFd for TokioCharDevice {
+    #[inline]
+    fn as_raw_read_fd(&self) -> RawFd {
+        self.as_raw_fd()
+    }
+
+    #[inline]
+    fn as_raw_write_fd(&self) -> RawFd {
+        self.as_raw_fd()
+    }
+}
+
+#[cfg(not(windows))]
+impl AsReadWriteFd for TokioCharDevice {
+    #[inline]
+    fn as_read_fd(&self) -> BorrowedFd<'_> {
+        self.as_fd()
+    }
+
+    #[inline]
+    fn as_write_fd(&self) -> BorrowedFd<'_> {
+        self.as_fd()
+    }
+}
+
+#[cfg(windows)]
+impl AsRawReadWriteHandleOrSocket for TokioCharDevice {
+    #[inline]
+    fn as_raw_read_handle_or_socket(&self) -> RawHandleOrSocket {
+        self.as_raw_handle_or_socket()
+    }
+
+    #[inline]
+    fn as_raw_write_handle_or_socket(&self) -> RawHandleOrSocket {
+        self.as_raw_handle_or_socket()
+    }
+}
+
+#[cfg(windows)]
+impl AsReadWriteHandleOrSocket for TokioCharDevice {
+    #[inline]
+    fn as_read_handle_or_socket(&self) -> BorrowedHandleOrSocket<'_> {
+        self.as_handle_or_socket()
+    }
+
+    #[inline]
+    fn as_write_handle_or_socket(&self) -> BorrowedHandleOrSocket<'_> {
+        self.as_handle_or_socket()
+    }
+}
